==> haskell-hslua-list-1.1.3-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-list
version:              1.1.3
visibility:           public
id:                   hslua-list-1.1.3-7vp0r4rne0qFMAfWrM9vgY
key:                  hslua-list-1.1.3-7vp0r4rne0qFMAfWrM9vgY
license:              MIT
copyright:            © 2022-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Opinionated, but extensible Lua list type.
description:          List type for Lua, with a Haskell interface.
category:             Foreign
abi:                  ad29f77336c2e61604f8f041896f4787
exposed:              True
exposed-modules:      HsLua.List
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-list-1.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-list-1.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-list-1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-list
hs-libraries:         HShslua-list-1.1.3-7vp0r4rne0qFMAfWrM9vgY
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hslua-core-2.3.1-5s7Ghn5wehALS31Fa4HycU

haddock-interfaces:   /usr/share/doc/haskell-hslua-list/html/hslua-list.haddock
haddock-html:         /usr/share/doc/haskell-hslua-list/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-list-1.1.3-65-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-list
version:              1.1.3
visibility:           public
id:                   hslua-list-1.1.3-1Lq9paPzo4i36xd7PbKBwz
key:                  hslua-list-1.1.3-1Lq9paPzo4i36xd7PbKBwz
license:              MIT
copyright:            © 2022-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Opinionated, but extensible Lua list type.
description:          List type for Lua, with a Haskell interface.
category:             Foreign
abi:                  f847746f1761c254b16c1d505abff3ad
exposed:              True
exposed-modules:      HsLua.List
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-list-1.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-list-1.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-list-1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-list
hs-libraries:         HShslua-list-1.1.3-1Lq9paPzo4i36xd7PbKBwz
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hslua-core-2.3.1-KDBdVRNXu6yGRxMauHVz2J

haddock-interfaces:   /usr/share/doc/haskell-hslua-list/html/hslua-list.haddock
haddock-html:         /usr/share/doc/haskell-hslua-list/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
